Module traits

Module traits 

Structs

VecRecordStore
Default in-memory RecordStore backed by a Vec, zero-config.

Enums

JudgeVerdict

Traits

BlockIndex
Opaque blocking index.
Blocker
Extracts blocking keys from records and looks up candidates in an index.
Clusterer
Groups scored pairs into entity clusters.
Comparator
EntityStore
Persistent store for resolved entities.
IntoRecord
Convert an external row type into a Record.
Judge
Neural re-ranker that adjudicates borderline record pairs.
RecordStore
Backing store for records used during ingestion and batch runs.
Scorer

Type Aliases

Result