IntoRecord

Trait IntoRecord 

pub trait IntoRecord {
    // Required method
    fn into_record(self, id: RecordId) -> Record;
}
Convert an external row type into a Record.

Implement this in an adapter crate (e.g. zer-adapters) for foreign row types such as a Polars LazyFrame row or an Arrow RecordBatch row. The id parameter lets callers assign a stable RecordId.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors