Module field_mapping
zer_
core
1.0.1
Module field_
mapping
Module Items
Structs
Enums
In crate zer_
core
zer_core
Module
field_
mapping
Structs

Field
Mapping
Declares how one field from source A maps to one field from source B.
Enums

Null
Policy
How the comparator treats a field pair where one or both values are absent.